utils

package
v0.0.0-...-82282fc Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 26, 2024 License: GPL-3.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ArgExists

func ArgExists(arg int) bool

Returns boolean based on if the argument exists or not

func Check

func Check(exception error)

Simple error checking

func GetArgName

func GetArgName(arg int) string

Returns argumeent name

func IsArg

func IsArg(toGet string, arg int) bool

Returns boolean based on if the argument exists and is named the same or not

Types

This section is empty.

Jump to