package
Version:
v0.0.0-...-82282fc
Opens a new window with list of versions in this module.
Published: Jul 26, 2024
License: GPL-3.0
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Returns boolean based on if the argument exists or not
func Check(exception error)
Simple error checking
Returns boolean based on if the argument
exists and is named the same or not
Source Files
¶
Click to show internal directories.
Click to hide internal directories.